@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudxf.org>
+ * Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0r@eudxf.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "addspot.h"
 #include "changefreq.h"
 
+void send_bandswitch(int freq);
 
 
 int callinput(void)
@@ -97,7 +98,7 @@ extern int rignumber;
 
 
 int  i, j, ii, t, x = 0, y=0,  xx;
-char instring[2];
+char instring[2] = { 0, 0 };
 char dupecall[17];
 char speedbuf[3] = "";
 char weightbuf[5];
@@ -105,8 +106,6 @@ static int lastwindow;
 
 instring[1] = '\0';
 
-void send_bandswitch(int freq);
-
 if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD );
 else     attron(COLOR_PAIR(NORMCOLOR) );
 
@@ -134,7 +133,6 @@ printcall();
 
 				x = onechar();
 
-
 			}
 		 	nodelay(stdscr, FALSE);
 
@@ -305,11 +303,11 @@ printcall();
 			{
 					strncpy(speedbuf, speedstr +  (2  *  keyspeed), 2);
 					speedbuf[2] =  '\0';
-					nicebox(1,1,2,10,"Cw");
+					nicebox(1,1,2,11,"Cw");
 					attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
-					mvprintw(2,2,"Speed: %s", speedbuf);
-					if (weight < 0) mvprintw(3,2,"Weight:%d", weight);
-					else mvprintw(3,2, "weight: %d", weight);
+					mvprintw(2,2,"Speed: %s  ", speedbuf);
+					if (weight < 0) mvprintw(3,2,"Weight:%d ", weight);
+					else mvprintw(3,2, "weight: %d  ", weight);
 					mvprintw(3,10,"");
 						refresh();
 						x = onechar();
@@ -319,26 +317,43 @@ printcall();
 							refresh();
 							weightbuf[0]=x;
 							x = onechar();
-							mvprintw(3,10, "%c", (char)x);
-							refresh();
-							weightbuf[1]=x;
-							weightbuf[2]='\0';
-						}else if (x == 27) {
-							x = -1;
+							if (x != 27)
+							{
+								mvprintw(3,10, "%c", (char)x);
+								refresh();
+								weightbuf[1]=x;
+								weightbuf[2]='\0';
+								x = onechar();
+							}
+							if (x != 27)
+							{
+								mvprintw(3,11, "%c", (char)x);
+								refresh();
+								weightbuf[2]=x;
+								weightbuf[3]='\0';
+							}
 						} else {
 							weightbuf[0]=x;
 							weightbuf[1]='\0';
+							mvprintw(3,10, "%c", (char)x);
+							refresh();
+							x = onechar();
+							if (x != 27)
+							{
+								weightbuf[1]=x;
+								weightbuf[2]='\0';
+							}
 						}
 						x = -1;
 						weight = atoi(weightbuf);
-						if (weight > -6 && weight < 6) {
+						if (weight > -51 && weight < 50) {
 						netkeyer(K_WEIGHT, weightbuf);
 						}
 					attron(COLOR_PAIR(COLOR_WHITE) | A_STANDOUT);
-					mvprintw(1,1,"            ");
-					mvprintw(2,1,"            ");
-					mvprintw(3,1,"            ");
-					mvprintw(4,1,"            ");
+					mvprintw(1,1,"             ");
+					mvprintw(2,1,"             ");
+					mvprintw(3,1,"             ");
+					mvprintw(4,1,"             ");
 					printcall();
 
 
