@@ -518,7 +518,7 @@ strcpy(parameters[49],  "CWMODE");
 						mvprintw(24,0, "keyer not active; switching to SSB");
 						trxmode = SSBMODE;
 						clear_display();
-					}
+					}				
 				}
 
 			}
@@ -1080,7 +1080,8 @@ const char eom[2] = {'\015' , '\0'};
 
 			int j = 0;
 
-			i = read (fdSertnc, inputline, BUFFERSIZE-1);
+//			i = read (fdSertnc, inputline, BUFFERSIZE-1);	### bug fix
+			i = read (fdSertnc, inputline, sizeof(inputline));
 
 			if (i > 0) {
 				for (j=0; j<i; j++){
