@@ -38,6 +38,7 @@ extern char ph_message[14][40];
 extern char comment[];
 extern int cqww;
 extern char cqzone[];
+extern char itustr[];
 extern char cq_return[];
 extern char sp_return[];
 extern int cury,curx;
@@ -48,6 +49,12 @@ extern int simulator;
 extern int simulator_mode;
 extern int lan_mutex;
 extern int ctcomp;
+extern int wazmult;
+extern int itumult;
+extern int qsonum;
+extern int exchange_serial;
+extern char tonestr[];
+
 int callreturn = 0;
 int qrg_out = 0;
 int time_out = 0;
@@ -73,7 +80,7 @@ else
 
   if (qrg_out == 0) {
 
- 	if ((trxmode == CWMODE) && (callreturn == '\n') && ctcomp == 1) {
+ 	if ((trxmode == CWMODE || trxmode == DIGIMODE) && (callreturn == '\n') && ctcomp == 1) {
  		callreturn = 92;
 		strcpy(comment, cqzone);
 	}
@@ -91,14 +98,20 @@ else
   	if (callreturn == '\n' && strlen(hiscall) >= 3 )
    	{
 
-    		if  ((cqmode ==  CQ ) && (contest == CONTEST  ) && (defer_store == 0)){         /* contest */
-				if (trxmode == CWMODE)
+    		if (!strlen(comment) && contest == CONTEST && !ctcomp && defer_store)
+		    defer_store = 0;
+		if  ((cqmode ==  CQ ) && (contest == CONTEST  ) && (defer_store == 0)){         /* contest */
+				if (trxmode == CWMODE || trxmode == DIGIMODE)
     				strcpy(buffer,  message[2]);      /*  send F3  on  ENTER  */
-				else
+				else {
 						play_file(ph_message[2]);
-
+						if (exchange_serial == 1)
+							mvprintw(13,29, "Serial number: %d", qsonum);
+							refresh();
+				}
 
 			if (simulator != 0) {
+				strcpy (tonestr, "700");
 				write_tone();
 				if (strstr(hiscall, "?") != NULL)
 					simulator_mode = 3;
@@ -106,11 +119,14 @@ else
 					simulator_mode =2;
 			}
 
-			if (cqww==1){
+			if ( (cqww==1) || (wazmult==1) || (itumult==1)  ){
 
    				if(recall_exchange() == -1) {
-       				strcpy (comment, cqzone);            /* fill in the zone */
-           		}
+                 if  (itumult ==1)
+                    strcpy (comment, itustr);            /* fill in the ITUzone */
+                 else
+                    strcpy (comment, cqzone);            /* fill in the CQzone */
+             }
 
 				if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
 				else attron(COLOR_PAIR(NORMCOLOR));
@@ -156,11 +172,14 @@ else
                  			}
         			}
 
-				if (trxmode == CWMODE)
+				if (trxmode == CWMODE || trxmode == DIGIMODE)
     		 		sendspcall();
-				else
+				else {
 					play_file(ph_message[5]);
-
+						if (exchange_serial == 1)
+							mvprintw(13,29, "Serial number: %d", qsonum);
+							refresh();
+				}
     		 	callreturn  = 0;
     		 	defer_store = 1;
     		}
@@ -168,25 +187,24 @@ else
 		    	defer_store ++;
 		    	callreturn = 0;
 		}
-		else
-		{
-		    	if  ((cqmode == CQ ) &&  (contest  == CONTEST )  &&  (defer_store > 1)){
-					if (trxmode == CWMODE){
+		else if (defer_store > 1) {
+		    	if  ((cqmode == CQ ) &&  (contest  == CONTEST )){
+					if (trxmode == CWMODE || trxmode == DIGIMODE){
 		     			strcat(buffer, cq_return);	/* send cq return */
 						sendbuf();
 						if (simulator !=0)     simulator_mode = 1;
 						if (simulator !=0)    write_tone();
 					}
-					else
+					else {
 						play_file(ph_message[13]);
-
+					}
 
 		     		defer_store = 0;
 
 		    	}
 
-		    	if  ((cqmode == S_P ) &&  (contest  == CONTEST )  &&  (defer_store > 1)){
-					if (trxmode == CWMODE){
+		    	if  ((cqmode == S_P ) &&  (contest  == CONTEST )){
+					if (trxmode == CWMODE || trxmode == DIGIMODE){
 		     			strcat(buffer, sp_return);
 						sendbuf();                                   /* send S&P return */
 					}
