@@ -82,6 +82,7 @@
   int two_eu_three_dx_points=0;
   int ssbpoints;
   int cwpoints;
+  int lowband_point_mult = 0;
   int sc_sidetone;
   char sc_volume[3] = "";
   /* LZ3NY mods */
@@ -142,6 +143,7 @@
   int mults_per_band = 1;		/* mults count per band */
   int shortqsonr =  LONGCW;     /*   1  =  short  cw char in exchange              */
   int cluster = NOCLUSTER;      /*   0 = OFF, 1 = FOLLOW     2  = spots  3 = all   */
+  int clusterlog = 0;		/* clusterlog on/off */
   int searchflg  = 0;		    /*   1  = display search  window */
   int show_time=0;
   int cqmode  = CQ;             /* 1  = CQ  0 = S&P  */
@@ -250,6 +252,9 @@ int miniterm = 0;
 	float rigfreq;		/* input frequency  */
 	int outfreq;             /* output  to rig */
 #endif
+	int ssb_bandwidth = 3000;
+	int cw_bandwidth = 0;
+	int nobandchange  = 0;
 	int serial_rate = 2400;
 	int rig_port=0;
 	char rigportname[40];
