@@ -1,6 +1,6 @@
 /*
 * Tlf - contest logging program for amateur radio operators
-* Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+* Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0rct@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -134,6 +134,7 @@ int parse_logcfg(char *inputbuffer){
 	extern int rit;
 	extern int shortqsonr;
 	extern int cluster;
+	extern int clusterlog;
 	extern int showscore_flag;
 	extern int searchflg;
 	extern int announcefilter;
@@ -170,7 +171,7 @@ int parse_logcfg(char *inputbuffer){
 	extern char bc_hostaddress[MAXNODES][16];
 	extern int lan_active;
 	extern char thisnode;
-	extern char nodes;
+	extern int nodes;
 	extern int node;
 	extern int cqwwm2;
 	extern int landebug;
@@ -203,6 +204,7 @@ int parse_logcfg(char *inputbuffer){
 	extern int bandindexarray[];
 	extern int ssbpoints;
 	extern int cwpoints;
+	extern int lowband_point_mult;
 	extern int sc_sidetone;
 	extern char sc_volume[];
 
@@ -232,6 +234,8 @@ extern int scale_values[];
 extern char sc_device[40];
 extern char controllerport[80];		// port for multi-mode controller
 extern char clusterlogin[];
+extern int cw_bandwidth;
+extern int nobandchange;
 
 
 
@@ -271,62 +275,62 @@ extern char clusterlogin[];
 		"BANDMAP",
 		"SPOTLIST",
 		"SCOREWINDOW",
-		"CHECKWINDOW",					/* 35 */
+		"CHECKWINDOW",			/* 35 */
 		"FILTER",
 		"SEND_DE",
 		"CWSPEED",
-		"TONE",
-		"WEIGHT",                           /* 40 */
+		"CWTONE",
+		"WEIGHT",                        /* 40 */
 		"TXDELAY",
 		"SUNSPOTS",
 		"SFI",
 		"SHOW_FREQUENCY",
-		"EDITOR",							/* 45 */
+		"EDITOR",			/* 45 */
 		"PARTIALS",
 		"USEPARTIALS",
 		"POWERMULT_5",
 		"POWERMULT_2",
-		"POWERMULT_1",    							/* 50 */
+		"POWERMULT_1", 			/* 50 */
 		"MANY_CALLS",
 		"SERIAL_EXCHANGE",
 		"COUNTRY_MULT",
 		"2EU3DX_POINTS",
-		"PORTABLE_MULT_2", 								/* 55 */
+		"PORTABLE_MULT_2",    		/* 55 */
 		"MIXED",
 		"TELNETHOST=",
 		"TELNETPORT=",
-		"TNCPORT=" ,
-		"FIFO_INTERFACE",                                   /* 60 */
+		"TNCPORT=" , 
+		"FIFO_INTERFACE",                /* 60 */
 		"RIGMODEL=",
 		"RIGSPEED=",
 		"TNCSPEED=",
 		"RIGPORT=" ,
-		"NETKEYER",                                               /* 65 */
+		"NETKEYER",                       /* 65 */
 		"NETKEYERPORT=",
 		"NETKEYERHOST=",
 		"ADDNODE=",
 		"THISNODE=",
-		"CQWW_M2",                                                   /* 70 */
+		"CQWW_M2",                         /* 70 */
 		"LAN_DEBUG",
 		"ALT_0=",
 		"ALT_1=",
 		"ALT_2=",
-		"ALT_3=",						/* 75 */
+		"ALT_3=",			/* 75 */
 		"ALT_4=",
 		"ALT_5=",
 		"ALT_6=",
 		"ALT_7=",
-		"ALT_8=",                                               /* 80 */
+		"ALT_8=",                            /* 80 */
 		"ALT_9=",
 		"CALLUPDATE",
 		"TIME_OFFSET=",
 		"TIME_MASTER" ,
-		"CTCOMPATIBLE",                                /*  85  */
+		"CTCOMPATIBLE",                        /*  85  */
 		"TWO_POINTS",
 		"MULT_LIST=",
 		"SERIAL+SECTION",
 		"SECTION_MULT",
-		"MARKERS=",                   					/* 90 */
+		"MARKERS=",                		/* 90 */
 		"DX_&_SECTIONS",
 		"MARKERDOTS=",
 		"MARKERCALLS=",
@@ -380,7 +384,14 @@ extern char clusterlogin[];
 		"MFJ1278_KEYER=", 		/* 140 */
 		"CLUSTERLOGIN=",
 		"ORION_KEYER",
-		"INITIAL_EXCHANGE="
+		"INITIAL_EXCHANGE=",
+		"CWBANDWIDTH=",
+		"LOWBAND_DOUBLE",		/* 145 */
+		"CLUSTER_LOG",
+		"",
+		"",
+		""
+		
 	};
 
 	char teststring[80];
@@ -554,7 +565,7 @@ extern char clusterlogin[];
 			case 39 : {
 				buff[0] = '\0';
 				strcat(buff, inputbuffer + 5);
-				if ((atoi(buff) > 199) && (atoi(buff) < 1000)){
+				if ((atoi(buff) > -1) && (atoi(buff) < 1001)){
 					strcpy(tonestr, buff);
 					tonestr[3] = '\0';
 				}
@@ -1091,7 +1102,7 @@ extern char clusterlogin[];
 			case 137: {  // sound card volume (default = 70)
 				buff[0] = '\0';
 				strncat(buff, inputbuffer + 16, 2);
-				if (atoi(buff) > 0 && atoi(buff) < 100)
+				if (atoi(buff) > -1 && atoi(buff) < 101)
 					strcpy(sc_volume, buff);
 				else
 					strcpy(sc_volume, "70");
@@ -1136,6 +1147,19 @@ extern char clusterlogin[];
 				exchange_list[strlen(exchange_list)-1] = '\0';
 				break;
 			}
+			case 144 : {
+				cw_bandwidth=atoi(inputbuffer + 12);
+				if (cw_bandwidth == 0) nobandchange=1;
+				break;
+			}
+			case 145 : {
+					lowband_point_mult = 1;
+					break;
+			}
+			case 146 : {
+					clusterlog = 1;
+					break;
+			}
 
 		}
 
